@@ -51,7 +51,8 @@ class Flag(object):
     .parser - an ArgumentParser object;
     .serializer - an ArgumentSerializer object;
     .allow_override - the flag may be redefined without raising an error;
-    .allow_override_cpp - the flag may be redefined despite shadowing a C++ flag
+    .allow_hide_cpp - the flag may be redefined despite hiding a C++ flag with
+                      the same name;
     .using_default_value - the flag value has not been set by user;
     .allow_overwrite - the flag may be parsed more than once without raising
                        an error, the last set value will be used.
@@ -76,7 +77,7 @@ class Flag(object):
 
   def __init__(self, parser, serializer, name, default, help_string,
                short_name=None, boolean=False, allow_override=False,
-               allow_override_cpp=False, allow_overwrite=True,
+               allow_hide_cpp=False, allow_overwrite=True,
                parse_default=True):
     self.name = name
 
@@ -90,7 +91,7 @@ class Flag(object):
     self.parser = parser
     self.serializer = serializer
     self.allow_override = allow_override
-    self.allow_override_cpp = allow_override_cpp
+    self.allow_hide_cpp = allow_hide_cpp
     self.allow_overwrite = allow_overwrite
     self.using_default_value = True
     self.value = None
@@ -273,7 +274,6 @@ class BooleanFlag(Flag):
   def __init__(self, name, default, help, short_name=None, **args):  # pylint: disable=redefined-builtin
     p = argument_parser.BooleanParser()
     Flag.__init__(self, p, None, name, default, help, short_name, 1, **args)
-    if not self.help: self.help = 'a boolean value'
 
 
 class EnumFlag(Flag):
@@ -285,11 +285,6 @@ class EnumFlag(Flag):
     p = argument_parser.EnumParser(enum_values, case_sensitive)
     g = argument_parser.ArgumentSerializer()
     Flag.__init__(self, p, g, name, default, help, short_name, **args)
-    if not self.help:
-      if case_sensitive:
-        self.help = 'an enum string'
-      else:
-        self.help = 'a case-insensitive enum string'
     self.help = '<%s>: %s' % ('|'.join(enum_values), self.help)
 
   def _WriteCustomInfoInXMLFormat(self, outfile, indent):
